@@ -14,7 +14,7 @@
  *  ChangeLog:
  *
  *  --------------------------------------------------------------------
- *  Copyright 2002-2004 Andreas Aardal Hanssen
+ *  Copyright 2002-2005 Andreas Aardal Hanssen
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -72,12 +72,16 @@ namespace {
 	}
 				 
 	struct stat mystat;
-	logger << "possible crash detected. waiting for mailbox lock " << lock << "." << endl;
 	if (lstat(lock.c_str(), &mystat) == 0) {
 	  if ((time(0) - mystat.st_ctime) > 300) {
-	    if (unlink(lock.c_str()) == 0) continue;
-	    else logger << "failed to force mailbox lock: " << lock
-			<< ", " << string(strerror(errno)) << endl;
+	    if (unlink(lock.c_str()) == 0) {
+              logger << "5 minute old lock detected: " << lock
+                     << ", lock deleted." << endl;
+              continue;
+	    } else {
+              logger << "failed to force mailbox lock: " << lock
+                     << ", " << string(strerror(errno)) << endl;
+            }
 	  }
 	} else {
 	  if (errno != ENOENT) {
@@ -283,8 +287,9 @@ Maildir::ScanResult Maildir::scan(bool forceScan)
     }
 
     // move files from new/ to cur/
+    string newName = curpath + pdirent->d_name;
     if (rename((newpath + pdirent->d_name).c_str(), 
-	       (curpath + pdirent->d_name).c_str()) != 0) {
+	       (newName + ":2,").c_str()) != 0) {
       logger << "error moving messages from"
 	" new to cur: skipping " << newpath 
 	     << pdirent->d_name << ": " << strerror(errno) << endl;
