@@ -14,7 +14,7 @@
  *  ChangeLog:
  *
  *  --------------------------------------------------------------------
- *  Copyright 2002-2004 Andreas Aardal Hanssen
+ *  Copyright 2002-2005 Andreas Aardal Hanssen
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -180,7 +180,7 @@ bool Session::parseRequestLine(int argc, char * argv[])
   args.addOptional("s|ssl", "Toggle enabling of SSL", true);
   args.addOptional("c|conf", "Sets the path to the config file", false);
   args.addOptional("a|allow-plain", "Allow authentication when not in SSL", true);
-  args.addOptional("p|auth-penalty", "Sets the auth penalty", false);
+  args.addOptional("auth-penalty", "Sets the auth penalty", false);
   args.addOptional("d|disable-starttls", "Toggles disabling of STARTTLS", false);
   args.addOptional("L|logtype", "Sets the method used for logging", false);
   args.addOptional("I|ip-variable", "Sets the env variable that contains the remote IP", false);
@@ -571,7 +571,7 @@ bool Session::saveSubscribes(void) const
     }
   }
   
-  if (fsync(fd) != 0 || close(fd) != 0) {
+  if (fsync(fd) != 0 && errno != EINVAL || close(fd) != 0) {
       logger << "failed to close " << ftemplate 
 	     << ": " << strerror(errno) << endl;
       delete [] ftemplate;
